summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMartin Pool <mbp@sourcefrog.net>2001-02-26 10:27:09 +0000
committerMartin Pool <mbp@sourcefrog.net>2001-02-26 10:27:09 +0000
commita656f30716c174220018cb30a0e9c6e0ae2eaa14 (patch)
tree275cd9178f3a69677304109785409ed3206c7219
parent297f4186386e8c24529166e74ed1426920f13423 (diff)
downloadlibrsync-a656f30716c174220018cb30a0e9c6e0ae2eaa14.tar.gz
Rename to isprefix().
-rw-r--r--isprefix.c8
-rw-r--r--isprefix.driver.c8
-rw-r--r--isprefix.h6
3 files changed, 11 insertions, 11 deletions
diff --git a/isprefix.c b/isprefix.c
index 34fc27c..6a26484 100644
--- a/isprefix.c
+++ b/isprefix.c
@@ -1,8 +1,8 @@
-/*= -*- c-file-style: "linux" -*-
+/*= -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
* libhsync -- dynamic caching and delta update in HTTP
* $Id$
*
- * Copyright (C) 2000 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2000, 2001 by Martin Pool <mbp@samba.org>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public License
@@ -22,11 +22,11 @@
#include "isprefix.h"
-/*
+/**
* Return true if TIP is a prefix of ICEBERG.
*/
int
-strisprefix(char const *tip, char const *iceberg)
+isprefix(char const *tip, char const *iceberg)
{
while (*tip) {
if (*tip != *iceberg)
diff --git a/isprefix.h b/isprefix.h
index 10b634e..6bb972e 100644
--- a/isprefix.h
+++ b/isprefix.h
@@ -1,8 +1,8 @@
-/*= -*- c-file-style: "linux" -*-
+/*= -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
* libhsync -- dynamic caching and delta update in HTTP
* $Id$
*
- * Copyright (C) 2000 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2000, 2001 by Martin Pool <mbp@samba.org>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public License
@@ -23,4 +23,4 @@
/*
* Return true if TIP is a prefix of ICEBERG.
*/
-int strisprefix(char const *tip, char const *iceberg);
+int isprefix(char const *tip, char const *iceberg);
diff --git a/isprefix.driver.c b/isprefix.driver.c
index 881d5c2..5581ab6 100644
--- a/isprefix.driver.c
+++ b/isprefix.driver.c
@@ -1,4 +1,4 @@
-/*= -*- c-file-style: "linux" -*-
+/*= -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
* libhsync -- dynamic caching and delta update in HTTP
* $Id$
*
@@ -31,7 +31,7 @@ static void usage(void)
}
/*
* Test driver for strisprefix. Compares the two parameters; returns
* true (0) if a prefix, false (1) otherwise.
*/
int main(int argc, char **argv)
@@ -41,12 +41,12 @@ int main(int argc, char **argv)
}
if (strcmp(argv[1], "!")) {
- return !strisprefix(argv[1], argv[2]);
+ return !isprefix(argv[1], argv[2]);
} else {
/* inverted */
if (argc < 4) {
usage();
}
- return strisprefix(argv[2], argv[3]);
+ return isprefix(argv[2], argv[3]);
}
}
@@ -31,7 +31,7 @@ static void usage(void)
}
/*
- * Test driver for strisprefix. Compares the two parameters; returns
+ * Test driver for isprefix. Compares the two parameters; returns
* true (0) if a prefix, false (1) otherwise.
*/